{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Save AR6 timeseries to database\n",
    "\n",
    "1. Download AR6 timeseries output\n",
    "1. Rename\n",
    "1. Save to database"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "application/javascript": [
       "\n",
       "            setTimeout(function() {\n",
       "                var nbb_cell_id = 1;\n",
       "                var nbb_unformatted_code = \"%load_ext nb_black\";\n",
       "                var nbb_formatted_code = \"%load_ext nb_black\";\n",
       "                var nbb_cells = Jupyter.notebook.get_cells();\n",
       "                for (var i = 0; i < nbb_cells.length; ++i) {\n",
       "                    if (nbb_cells[i].input_prompt_number == nbb_cell_id) {\n",
       "                        if (nbb_cells[i].get_text() == nbb_unformatted_code) {\n",
       "                             nbb_cells[i].set_text(nbb_formatted_code);\n",
       "                        }\n",
       "                        break;\n",
       "                    }\n",
       "                }\n",
       "            }, 500);\n",
       "            "
      ],
      "text/plain": [
       "<IPython.core.display.Javascript object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "%load_ext nb_black"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "application/javascript": [
       "IPython.OutputArea.prototype._should_scroll = function(lines) { return false; }"
      ],
      "text/plain": [
       "<IPython.core.display.Javascript object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "/data/ubuntu-znicholls/miniconda3/envs/nicholls-et-al-2022-emulator-changes/lib/python3.7/site-packages/scmdata/database.py:21: TqdmExperimentalWarning: Using `tqdm.autonotebook.tqdm` in notebook mode. Use `tqdm.tqdm` instead to force console mode (e.g. in jupyter console)\n",
      "  import tqdm.autonotebook as tqdman\n"
     ]
    },
    {
     "data": {
      "application/javascript": [
       "\n",
       "            setTimeout(function() {\n",
       "                var nbb_cell_id = 2;\n",
       "                var nbb_unformatted_code = \"import glob\\nimport os.path\\nimport zipfile\\nfrom multiprocessing import Pool\\n\\nimport dotenv\\nimport pandas as pd\\nimport scmdata\\nimport scmdata.database\\nimport tqdm.autonotebook as tqdman\";\n",
       "                var nbb_formatted_code = \"import glob\\nimport os.path\\nimport zipfile\\nfrom multiprocessing import Pool\\n\\nimport dotenv\\nimport pandas as pd\\nimport scmdata\\nimport scmdata.database\\nimport tqdm.autonotebook as tqdman\";\n",
       "                var nbb_cells = Jupyter.notebook.get_cells();\n",
       "                for (var i = 0; i < nbb_cells.length; ++i) {\n",
       "                    if (nbb_cells[i].input_prompt_number == nbb_cell_id) {\n",
       "                        if (nbb_cells[i].get_text() == nbb_unformatted_code) {\n",
       "                             nbb_cells[i].set_text(nbb_formatted_code);\n",
       "                        }\n",
       "                        break;\n",
       "                    }\n",
       "                }\n",
       "            }, 500);\n",
       "            "
      ],
      "text/plain": [
       "<IPython.core.display.Javascript object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "import glob\n",
    "import os.path\n",
    "import zipfile\n",
    "from multiprocessing import Pool\n",
    "\n",
    "import dotenv\n",
    "import pandas as pd\n",
    "import scmdata\n",
    "import scmdata.database\n",
    "import tqdm.autonotebook as tqdman"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "application/javascript": [
       "\n",
       "            setTimeout(function() {\n",
       "                var nbb_cell_id = 3;\n",
       "                var nbb_unformatted_code = \"import utils\";\n",
       "                var nbb_formatted_code = \"import utils\";\n",
       "                var nbb_cells = Jupyter.notebook.get_cells();\n",
       "                for (var i = 0; i < nbb_cells.length; ++i) {\n",
       "                    if (nbb_cells[i].input_prompt_number == nbb_cell_id) {\n",
       "                        if (nbb_cells[i].get_text() == nbb_unformatted_code) {\n",
       "                             nbb_cells[i].set_text(nbb_formatted_code);\n",
       "                        }\n",
       "                        break;\n",
       "                    }\n",
       "                }\n",
       "            }, 500);\n",
       "            "
      ],
      "text/plain": [
       "<IPython.core.display.Javascript object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "import utils"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "application/javascript": [
       "\n",
       "            setTimeout(function() {\n",
       "                var nbb_cell_id = 4;\n",
       "                var nbb_unformatted_code = \"N_WORKERS = 32\";\n",
       "                var nbb_formatted_code = \"N_WORKERS = 32\";\n",
       "                var nbb_cells = Jupyter.notebook.get_cells();\n",
       "                for (var i = 0; i < nbb_cells.length; ++i) {\n",
       "                    if (nbb_cells[i].input_prompt_number == nbb_cell_id) {\n",
       "                        if (nbb_cells[i].get_text() == nbb_unformatted_code) {\n",
       "                             nbb_cells[i].set_text(nbb_formatted_code);\n",
       "                        }\n",
       "                        break;\n",
       "                    }\n",
       "                }\n",
       "            }, 500);\n",
       "            "
      ],
      "text/plain": [
       "<IPython.core.display.Javascript object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "N_WORKERS = 32"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "application/javascript": [
       "\n",
       "            setTimeout(function() {\n",
       "                var nbb_cell_id = 5;\n",
       "                var nbb_unformatted_code = \"variables_to_put_in_db = [\\n    \\\"*GSAT*\\\",\\n    \\\"*Exceed*\\\",\\n    \\\"*Emissions*\\\",\\n    \\\"*Forcing*\\\",\\n    \\\"*Concentrations*\\\",\\n]\\n\\n\\ndef read_file(f):\\n    ts = scmdata.ScmRun(f, lowercase_cols=True)\\n    out = ts.filter(variable=variables_to_put_in_db)\\n\\n    return out\\n\\n\\ndef determine_percentile(v):\\n    if \\\"Percentile\\\" not in v:\\n        return \\\"not_applicable\\\"\\n\\n    return v.split(\\\"|\\\")[-1].replace(\\\"th Percentile\\\", \\\"\\\")\\n\\n\\ndef determine_climate_model(v):\\n    if not any([cm in v for cm in [\\\"MAGICC\\\", \\\"FaIR\\\"]]):\\n        return \\\"not_applicable\\\"\\n\\n    if \\\"Percentile\\\" in v:\\n        return v.split(\\\"|\\\")[-2]\\n\\n    return v.split(\\\"|\\\")[-1]\\n\\n\\ndef strip_to_variable(v):\\n    out = v.replace(\\\"SR15 climate diagnostics|\\\", \\\"\\\").replace(\\n        \\\"AR6 climate diagnostics|\\\", \\\"\\\"\\n    )\\n\\n    if \\\"Percentile\\\" in out:\\n        out = \\\"|\\\".join(out.split(\\\"|\\\")[:-1])\\n\\n    if any([cm in v for cm in [\\\"MAGICC\\\", \\\"FaIR\\\"]]):\\n        out = \\\"|\\\".join(out.split(\\\"|\\\")[:-1])\\n\\n    return out\";\n",
       "                var nbb_formatted_code = \"variables_to_put_in_db = [\\n    \\\"*GSAT*\\\",\\n    \\\"*Exceed*\\\",\\n    \\\"*Emissions*\\\",\\n    \\\"*Forcing*\\\",\\n    \\\"*Concentrations*\\\",\\n]\\n\\n\\ndef read_file(f):\\n    ts = scmdata.ScmRun(f, lowercase_cols=True)\\n    out = ts.filter(variable=variables_to_put_in_db)\\n\\n    return out\\n\\n\\ndef determine_percentile(v):\\n    if \\\"Percentile\\\" not in v:\\n        return \\\"not_applicable\\\"\\n\\n    return v.split(\\\"|\\\")[-1].replace(\\\"th Percentile\\\", \\\"\\\")\\n\\n\\ndef determine_climate_model(v):\\n    if not any([cm in v for cm in [\\\"MAGICC\\\", \\\"FaIR\\\"]]):\\n        return \\\"not_applicable\\\"\\n\\n    if \\\"Percentile\\\" in v:\\n        return v.split(\\\"|\\\")[-2]\\n\\n    return v.split(\\\"|\\\")[-1]\\n\\n\\ndef strip_to_variable(v):\\n    out = v.replace(\\\"SR15 climate diagnostics|\\\", \\\"\\\").replace(\\n        \\\"AR6 climate diagnostics|\\\", \\\"\\\"\\n    )\\n\\n    if \\\"Percentile\\\" in out:\\n        out = \\\"|\\\".join(out.split(\\\"|\\\")[:-1])\\n\\n    if any([cm in v for cm in [\\\"MAGICC\\\", \\\"FaIR\\\"]]):\\n        out = \\\"|\\\".join(out.split(\\\"|\\\")[:-1])\\n\\n    return out\";\n",
       "                var nbb_cells = Jupyter.notebook.get_cells();\n",
       "                for (var i = 0; i < nbb_cells.length; ++i) {\n",
       "                    if (nbb_cells[i].input_prompt_number == nbb_cell_id) {\n",
       "                        if (nbb_cells[i].get_text() == nbb_unformatted_code) {\n",
       "                             nbb_cells[i].set_text(nbb_formatted_code);\n",
       "                        }\n",
       "                        break;\n",
       "                    }\n",
       "                }\n",
       "            }, 500);\n",
       "            "
      ],
      "text/plain": [
       "<IPython.core.display.Javascript object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "variables_to_put_in_db = [\n",
    "    \"*GSAT*\",\n",
    "    \"*Exceed*\",\n",
    "    \"*Emissions*\",\n",
    "    \"*Forcing*\",\n",
    "    \"*Concentrations*\",\n",
    "]\n",
    "\n",
    "\n",
    "def read_file(f):\n",
    "    ts = scmdata.ScmRun(f, lowercase_cols=True)\n",
    "    out = ts.filter(variable=variables_to_put_in_db)\n",
    "\n",
    "    return out\n",
    "\n",
    "\n",
    "def determine_percentile(v):\n",
    "    if \"Percentile\" not in v:\n",
    "        return \"not_applicable\"\n",
    "\n",
    "    return v.split(\"|\")[-1].replace(\"th Percentile\", \"\")\n",
    "\n",
    "\n",
    "def determine_climate_model(v):\n",
    "    if not any([cm in v for cm in [\"MAGICC\", \"FaIR\"]]):\n",
    "        return \"not_applicable\"\n",
    "\n",
    "    if \"Percentile\" in v:\n",
    "        return v.split(\"|\")[-2]\n",
    "\n",
    "    return v.split(\"|\")[-1]\n",
    "\n",
    "\n",
    "def strip_to_variable(v):\n",
    "    out = v.replace(\"SR15 climate diagnostics|\", \"\").replace(\n",
    "        \"AR6 climate diagnostics|\", \"\"\n",
    "    )\n",
    "\n",
    "    if \"Percentile\" in out:\n",
    "        out = \"|\".join(out.split(\"|\")[:-1])\n",
    "\n",
    "    if any([cm in v for cm in [\"MAGICC\", \"FaIR\"]]):\n",
    "        out = \"|\".join(out.split(\"|\")[:-1])\n",
    "\n",
    "    return out"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "application/javascript": [
       "\n",
       "            setTimeout(function() {\n",
       "                var nbb_cell_id = 6;\n",
       "                var nbb_unformatted_code = \"def save_files_to_db(flist, output_path, methodology, delete_first=True):\\n    print(f\\\"{len(flist)} files to read\\\")\\n\\n    output_db = scmdata.database.ScmDatabase(\\n        output_path,\\n        levels=(\\\"variable\\\", \\\"percentile\\\"),\\n    )\\n    if delete_first:\\n        output_db.delete()\\n\\n    with Pool(processes=N_WORKERS) as pool:\\n        print(f\\\"Reading files with {N_WORKERS} workers\\\")\\n        raw = pool.map(read_file, files_to_read)\\n        print(\\\"Finished\\\")\\n\\n    raw = scmdata.run_append(raw)\\n    display(raw)\\n\\n    mss = raw.meta[[\\\"model\\\", \\\"scenario\\\"]].drop_duplicates()\\n    display(mss)\\n\\n    to_save = raw.copy()\\n    to_save[\\\"percentile\\\"] = to_save[\\\"variable\\\"].apply(determine_percentile)\\n    to_save[\\\"methodology\\\"] = methodology\\n    to_save[\\\"climate_model\\\"] = to_save[\\\"variable\\\"].apply(determine_climate_model)\\n    to_save[\\\"variable\\\"] = to_save[\\\"variable\\\"].apply(strip_to_variable)\\n\\n    prefixes = [\\\"Infilled|\\\"]\\n    if any(v.startswith(\\\"Emissions\\\") for v in to_save.get_unique_meta(\\\"variable\\\")):\\n        prefixes.append(\\\"\\\")\\n\\n    for prefix in prefixes:\\n        co2_total_var = f\\\"{prefix}Emissions|CO2\\\"\\n\\n        if co2_total_var in to_save.get_unique_meta(\\\"variable\\\"):\\n            co2_total = to_save.filter(variable=co2_total_var)\\n            assert (\\n                co2_total.meta[[\\\"model\\\", \\\"scenario\\\"]].drop_duplicates().shape[0]\\n                == mss.shape[0]\\n            )\\n\\n        else:\\n            co2_total = (\\n                to_save.filter(variable=f\\\"{prefix}Emissions|CO2|AFOLU\\\")\\n                .add(\\n                    to_save.filter(\\n                        variable=f\\\"{prefix}Emissions|CO2|Energy and Industrial Processes\\\"\\n                    ),\\n                    op_cols={\\\"variable\\\": co2_total_var},\\n                )\\n                .convert_unit(\\\"Mt CO2/yr\\\")\\n            )\\n            to_save = to_save.append(co2_total)\\n\\n        co2_cumulative = (\\n            co2_total.interpolate(co2_total.filter(year=range(2015, 2100 + 1))[\\\"time\\\"])\\n            .integrate()\\n            .convert_unit(\\\"Gt CO2\\\")\\n        )\\n\\n        to_save = to_save.append(co2_cumulative)\\n\\n    display(to_save)\\n\\n    output_db.save(to_save)\";\n",
       "                var nbb_formatted_code = \"def save_files_to_db(flist, output_path, methodology, delete_first=True):\\n    print(f\\\"{len(flist)} files to read\\\")\\n\\n    output_db = scmdata.database.ScmDatabase(\\n        output_path,\\n        levels=(\\\"variable\\\", \\\"percentile\\\"),\\n    )\\n    if delete_first:\\n        output_db.delete()\\n\\n    with Pool(processes=N_WORKERS) as pool:\\n        print(f\\\"Reading files with {N_WORKERS} workers\\\")\\n        raw = pool.map(read_file, files_to_read)\\n        print(\\\"Finished\\\")\\n\\n    raw = scmdata.run_append(raw)\\n    display(raw)\\n\\n    mss = raw.meta[[\\\"model\\\", \\\"scenario\\\"]].drop_duplicates()\\n    display(mss)\\n\\n    to_save = raw.copy()\\n    to_save[\\\"percentile\\\"] = to_save[\\\"variable\\\"].apply(determine_percentile)\\n    to_save[\\\"methodology\\\"] = methodology\\n    to_save[\\\"climate_model\\\"] = to_save[\\\"variable\\\"].apply(determine_climate_model)\\n    to_save[\\\"variable\\\"] = to_save[\\\"variable\\\"].apply(strip_to_variable)\\n\\n    prefixes = [\\\"Infilled|\\\"]\\n    if any(v.startswith(\\\"Emissions\\\") for v in to_save.get_unique_meta(\\\"variable\\\")):\\n        prefixes.append(\\\"\\\")\\n\\n    for prefix in prefixes:\\n        co2_total_var = f\\\"{prefix}Emissions|CO2\\\"\\n\\n        if co2_total_var in to_save.get_unique_meta(\\\"variable\\\"):\\n            co2_total = to_save.filter(variable=co2_total_var)\\n            assert (\\n                co2_total.meta[[\\\"model\\\", \\\"scenario\\\"]].drop_duplicates().shape[0]\\n                == mss.shape[0]\\n            )\\n\\n        else:\\n            co2_total = (\\n                to_save.filter(variable=f\\\"{prefix}Emissions|CO2|AFOLU\\\")\\n                .add(\\n                    to_save.filter(\\n                        variable=f\\\"{prefix}Emissions|CO2|Energy and Industrial Processes\\\"\\n                    ),\\n                    op_cols={\\\"variable\\\": co2_total_var},\\n                )\\n                .convert_unit(\\\"Mt CO2/yr\\\")\\n            )\\n            to_save = to_save.append(co2_total)\\n\\n        co2_cumulative = (\\n            co2_total.interpolate(co2_total.filter(year=range(2015, 2100 + 1))[\\\"time\\\"])\\n            .integrate()\\n            .convert_unit(\\\"Gt CO2\\\")\\n        )\\n\\n        to_save = to_save.append(co2_cumulative)\\n\\n    display(to_save)\\n\\n    output_db.save(to_save)\";\n",
       "                var nbb_cells = Jupyter.notebook.get_cells();\n",
       "                for (var i = 0; i < nbb_cells.length; ++i) {\n",
       "                    if (nbb_cells[i].input_prompt_number == nbb_cell_id) {\n",
       "                        if (nbb_cells[i].get_text() == nbb_unformatted_code) {\n",
       "                             nbb_cells[i].set_text(nbb_formatted_code);\n",
       "                        }\n",
       "                        break;\n",
       "                    }\n",
       "                }\n",
       "            }, 500);\n",
       "            "
      ],
      "text/plain": [
       "<IPython.core.display.Javascript object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "def save_files_to_db(flist, output_path, methodology, delete_first=True):\n",
    "    print(f\"{len(flist)} files to read\")\n",
    "\n",
    "    output_db = scmdata.database.ScmDatabase(\n",
    "        output_path,\n",
    "        levels=(\"variable\", \"percentile\"),\n",
    "    )\n",
    "    if delete_first:\n",
    "        output_db.delete()\n",
    "\n",
    "    with Pool(processes=N_WORKERS) as pool:\n",
    "        print(f\"Reading files with {N_WORKERS} workers\")\n",
    "        raw = pool.map(read_file, files_to_read)\n",
    "        print(\"Finished\")\n",
    "\n",
    "    raw = scmdata.run_append(raw)\n",
    "    display(raw)\n",
    "\n",
    "    mss = raw.meta[[\"model\", \"scenario\"]].drop_duplicates()\n",
    "    display(mss)\n",
    "\n",
    "    to_save = raw.copy()\n",
    "    to_save[\"percentile\"] = to_save[\"variable\"].apply(determine_percentile)\n",
    "    to_save[\"methodology\"] = methodology\n",
    "    to_save[\"climate_model\"] = to_save[\"variable\"].apply(determine_climate_model)\n",
    "    to_save[\"variable\"] = to_save[\"variable\"].apply(strip_to_variable)\n",
    "\n",
    "    prefixes = [\"Infilled|\"]\n",
    "    if any(v.startswith(\"Emissions\") for v in to_save.get_unique_meta(\"variable\")):\n",
    "        prefixes.append(\"\")\n",
    "\n",
    "    for prefix in prefixes:\n",
    "        co2_total_var = f\"{prefix}Emissions|CO2\"\n",
    "\n",
    "        if co2_total_var in to_save.get_unique_meta(\"variable\"):\n",
    "            co2_total = to_save.filter(variable=co2_total_var)\n",
    "            assert (\n",
    "                co2_total.meta[[\"model\", \"scenario\"]].drop_duplicates().shape[0]\n",
    "                == mss.shape[0]\n",
    "            )\n",
    "\n",
    "        else:\n",
    "            co2_total = (\n",
    "                to_save.filter(variable=f\"{prefix}Emissions|CO2|AFOLU\")\n",
    "                .add(\n",
    "                    to_save.filter(\n",
    "                        variable=f\"{prefix}Emissions|CO2|Energy and Industrial Processes\"\n",
    "                    ),\n",
    "                    op_cols={\"variable\": co2_total_var},\n",
    "                )\n",
    "                .convert_unit(\"Mt CO2/yr\")\n",
    "            )\n",
    "            to_save = to_save.append(co2_total)\n",
    "\n",
    "        co2_cumulative = (\n",
    "            co2_total.interpolate(co2_total.filter(year=range(2015, 2100 + 1))[\"time\"])\n",
    "            .integrate()\n",
    "            .convert_unit(\"Gt CO2\")\n",
    "        )\n",
    "\n",
    "        to_save = to_save.append(co2_cumulative)\n",
    "\n",
    "    display(to_save)\n",
    "\n",
    "    output_db.save(to_save)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "411 files to read\n",
      "Reading files with 32 workers\n",
      "Finished\n"
     ]
    },
    {
     "data": {
      "text/plain": [
       "<scmdata.ScmRun (timeseries: 191937, timepoints: 107)>\n",
       "Time:\n",
       "\tStart: 1995-01-01T00:00:00\n",
       "\tEnd: 2105-01-01T00:00:00\n",
       "Meta:\n",
       "\t                        model region            scenario       unit  \\\n",
       "\t0               POLES_ADVANCE  World   ADVANCE_2030_WB2C   Mt BC/yr   \n",
       "\t1               POLES_ADVANCE  World   ADVANCE_2030_WB2C  Mt CH4/yr   \n",
       "\t2               POLES_ADVANCE  World   ADVANCE_2030_WB2C   Mt CO/yr   \n",
       "\t3               POLES_ADVANCE  World   ADVANCE_2030_WB2C  Mt CO2/yr   \n",
       "\t4               POLES_ADVANCE  World   ADVANCE_2030_WB2C  Mt CO2/yr   \n",
       "\t...                       ...    ...                 ...        ...   \n",
       "\t191932  REMIND-MAgPIE_1_7-3_0  World  EMF33_1.5C_cost100          K   \n",
       "\t191933  REMIND-MAgPIE_1_7-3_0  World  EMF33_1.5C_cost100          K   \n",
       "\t191934  REMIND-MAgPIE_1_7-3_0  World  EMF33_1.5C_cost100          K   \n",
       "\t191935  REMIND-MAgPIE_1_7-3_0  World  EMF33_1.5C_cost100          K   \n",
       "\t191936  REMIND-MAgPIE_1_7-3_0  World  EMF33_1.5C_cost100          K   \n",
       "\t\n",
       "\t                                                 variable  \n",
       "\t0                                            Emissions|BC  \n",
       "\t1                                           Emissions|CH4  \n",
       "\t2                                            Emissions|CO  \n",
       "\t3                                     Emissions|CO2|AFOLU  \n",
       "\t4           Emissions|CO2|Energy and Industrial Processes  \n",
       "\t...                                                   ...  \n",
       "\t191932  SR15 climate diagnostics|Surface Temperature (...  \n",
       "\t191933  SR15 climate diagnostics|Surface Temperature (...  \n",
       "\t191934  SR15 climate diagnostics|Surface Temperature (...  \n",
       "\t191935  SR15 climate diagnostics|Surface Temperature (...  \n",
       "\t191936  SR15 climate diagnostics|Surface Temperature (...  \n",
       "\t\n",
       "\t[191937 rows x 5 columns]"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>model</th>\n",
       "      <th>scenario</th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>POLES_ADVANCE</td>\n",
       "      <td>ADVANCE_2030_WB2C</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>467</th>\n",
       "      <td>MESSAGE_V_3</td>\n",
       "      <td>GEA_Eff_1p5C_Delay2020</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>934</th>\n",
       "      <td>MERGE-ETL_6_0</td>\n",
       "      <td>DAC15_50</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1401</th>\n",
       "      <td>GCAM_4_2</td>\n",
       "      <td>SSP5-45</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1868</th>\n",
       "      <td>IMAGE_3_0_1</td>\n",
       "      <td>ADVANCE_2030_WB2C</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>...</th>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>189602</th>\n",
       "      <td>AIM_2_1</td>\n",
       "      <td>EMF33_tax_lo_none</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>190069</th>\n",
       "      <td>POLES_ADVANCE</td>\n",
       "      <td>ADVANCE_2030_Med2C</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>190536</th>\n",
       "      <td>AIM_2_0</td>\n",
       "      <td>SSP2-Baseline</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>191003</th>\n",
       "      <td>IMAGE_3_0_2</td>\n",
       "      <td>EMF33_Med2C_limbio</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>191470</th>\n",
       "      <td>REMIND-MAgPIE_1_7-3_0</td>\n",
       "      <td>EMF33_1.5C_cost100</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "<p>411 rows × 2 columns</p>\n",
       "</div>"
      ],
      "text/plain": [
       "                        model                scenario\n",
       "0               POLES_ADVANCE       ADVANCE_2030_WB2C\n",
       "467               MESSAGE_V_3  GEA_Eff_1p5C_Delay2020\n",
       "934             MERGE-ETL_6_0                DAC15_50\n",
       "1401                 GCAM_4_2                 SSP5-45\n",
       "1868              IMAGE_3_0_1       ADVANCE_2030_WB2C\n",
       "...                       ...                     ...\n",
       "189602                AIM_2_1       EMF33_tax_lo_none\n",
       "190069          POLES_ADVANCE      ADVANCE_2030_Med2C\n",
       "190536                AIM_2_0           SSP2-Baseline\n",
       "191003            IMAGE_3_0_2      EMF33_Med2C_limbio\n",
       "191470  REMIND-MAgPIE_1_7-3_0      EMF33_1.5C_cost100\n",
       "\n",
       "[411 rows x 2 columns]"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/plain": [
       "<scmdata.ScmRun (timeseries: 193581, timepoints: 107)>\n",
       "Time:\n",
       "\tStart: 1995-01-01T00:00:00\n",
       "\tEnd: 2105-01-01T00:00:00\n",
       "Meta:\n",
       "\t         climate_model methodology                  model      percentile  \\\n",
       "\t0       not_applicable       SR1.5          POLES_ADVANCE  not_applicable   \n",
       "\t1       not_applicable       SR1.5          POLES_ADVANCE  not_applicable   \n",
       "\t2       not_applicable       SR1.5          POLES_ADVANCE  not_applicable   \n",
       "\t3       not_applicable       SR1.5          POLES_ADVANCE  not_applicable   \n",
       "\t4       not_applicable       SR1.5          POLES_ADVANCE  not_applicable   \n",
       "\t...                ...         ...                    ...             ...   \n",
       "\t193576  not_applicable       SR1.5                AIM_2_1  not_applicable   \n",
       "\t193577  not_applicable       SR1.5          POLES_ADVANCE  not_applicable   \n",
       "\t193578  not_applicable       SR1.5                AIM_2_0  not_applicable   \n",
       "\t193579  not_applicable       SR1.5            IMAGE_3_0_2  not_applicable   \n",
       "\t193580  not_applicable       SR1.5  REMIND-MAgPIE_1_7-3_0  not_applicable   \n",
       "\t\n",
       "\t       region            scenario       unit  \\\n",
       "\t0       World   ADVANCE_2030_WB2C   Mt BC/yr   \n",
       "\t1       World   ADVANCE_2030_WB2C  Mt CH4/yr   \n",
       "\t2       World   ADVANCE_2030_WB2C   Mt CO/yr   \n",
       "\t3       World   ADVANCE_2030_WB2C  Mt CO2/yr   \n",
       "\t4       World   ADVANCE_2030_WB2C  Mt CO2/yr   \n",
       "\t...       ...                 ...        ...   \n",
       "\t193576  World   EMF33_tax_lo_none     Gt CO2   \n",
       "\t193577  World  ADVANCE_2030_Med2C     Gt CO2   \n",
       "\t193578  World       SSP2-Baseline     Gt CO2   \n",
       "\t193579  World  EMF33_Med2C_limbio     Gt CO2   \n",
       "\t193580  World  EMF33_1.5C_cost100     Gt CO2   \n",
       "\t\n",
       "\t                                             variable  \n",
       "\t0                                        Emissions|BC  \n",
       "\t1                                       Emissions|CH4  \n",
       "\t2                                        Emissions|CO  \n",
       "\t3                                 Emissions|CO2|AFOLU  \n",
       "\t4       Emissions|CO2|Energy and Industrial Processes  \n",
       "\t...                                               ...  \n",
       "\t193576                       Cumulative Emissions|CO2  \n",
       "\t193577                       Cumulative Emissions|CO2  \n",
       "\t193578                       Cumulative Emissions|CO2  \n",
       "\t193579                       Cumulative Emissions|CO2  \n",
       "\t193580                       Cumulative Emissions|CO2  \n",
       "\t\n",
       "\t[193581 rows x 8 columns]"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "Saving to database: 0it [00:00, ?it/s]"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "411 files to read\n",
      "Reading files with 32 workers\n",
      "Finished\n"
     ]
    },
    {
     "data": {
      "text/plain": [
       "<scmdata.ScmRun (timeseries: 191937, timepoints: 107)>\n",
       "Time:\n",
       "\tStart: 1995-01-01T00:00:00\n",
       "\tEnd: 2105-01-01T00:00:00\n",
       "Meta:\n",
       "\t                        model region            scenario       unit  \\\n",
       "\t0               POLES_ADVANCE  World   ADVANCE_2030_WB2C   Mt BC/yr   \n",
       "\t1               POLES_ADVANCE  World   ADVANCE_2030_WB2C  Mt CH4/yr   \n",
       "\t2               POLES_ADVANCE  World   ADVANCE_2030_WB2C   Mt CO/yr   \n",
       "\t3               POLES_ADVANCE  World   ADVANCE_2030_WB2C  Mt CO2/yr   \n",
       "\t4               POLES_ADVANCE  World   ADVANCE_2030_WB2C  Mt CO2/yr   \n",
       "\t...                       ...    ...                 ...        ...   \n",
       "\t191932  REMIND-MAgPIE_1_7-3_0  World  EMF33_1.5C_cost100          K   \n",
       "\t191933  REMIND-MAgPIE_1_7-3_0  World  EMF33_1.5C_cost100          K   \n",
       "\t191934  REMIND-MAgPIE_1_7-3_0  World  EMF33_1.5C_cost100          K   \n",
       "\t191935  REMIND-MAgPIE_1_7-3_0  World  EMF33_1.5C_cost100          K   \n",
       "\t191936  REMIND-MAgPIE_1_7-3_0  World  EMF33_1.5C_cost100          K   \n",
       "\t\n",
       "\t                                                 variable  \n",
       "\t0                                            Emissions|BC  \n",
       "\t1                                           Emissions|CH4  \n",
       "\t2                                            Emissions|CO  \n",
       "\t3                                     Emissions|CO2|AFOLU  \n",
       "\t4           Emissions|CO2|Energy and Industrial Processes  \n",
       "\t...                                                   ...  \n",
       "\t191932  SR15 climate diagnostics|Surface Temperature (...  \n",
       "\t191933  SR15 climate diagnostics|Surface Temperature (...  \n",
       "\t191934  SR15 climate diagnostics|Surface Temperature (...  \n",
       "\t191935  SR15 climate diagnostics|Surface Temperature (...  \n",
       "\t191936  SR15 climate diagnostics|Surface Temperature (...  \n",
       "\t\n",
       "\t[191937 rows x 5 columns]"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>model</th>\n",
       "      <th>scenario</th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>POLES_ADVANCE</td>\n",
       "      <td>ADVANCE_2030_WB2C</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>467</th>\n",
       "      <td>MESSAGE_V_3</td>\n",
       "      <td>GEA_Eff_1p5C_Delay2020</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>934</th>\n",
       "      <td>MERGE-ETL_6_0</td>\n",
       "      <td>DAC15_50</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1401</th>\n",
       "      <td>GCAM_4_2</td>\n",
       "      <td>SSP5-45</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1868</th>\n",
       "      <td>IMAGE_3_0_1</td>\n",
       "      <td>ADVANCE_2030_WB2C</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>...</th>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>189602</th>\n",
       "      <td>AIM_2_1</td>\n",
       "      <td>EMF33_tax_lo_none</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>190069</th>\n",
       "      <td>POLES_ADVANCE</td>\n",
       "      <td>ADVANCE_2030_Med2C</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>190536</th>\n",
       "      <td>AIM_2_0</td>\n",
       "      <td>SSP2-Baseline</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>191003</th>\n",
       "      <td>IMAGE_3_0_2</td>\n",
       "      <td>EMF33_Med2C_limbio</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>191470</th>\n",
       "      <td>REMIND-MAgPIE_1_7-3_0</td>\n",
       "      <td>EMF33_1.5C_cost100</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "<p>411 rows × 2 columns</p>\n",
       "</div>"
      ],
      "text/plain": [
       "                        model                scenario\n",
       "0               POLES_ADVANCE       ADVANCE_2030_WB2C\n",
       "467               MESSAGE_V_3  GEA_Eff_1p5C_Delay2020\n",
       "934             MERGE-ETL_6_0                DAC15_50\n",
       "1401                 GCAM_4_2                 SSP5-45\n",
       "1868              IMAGE_3_0_1       ADVANCE_2030_WB2C\n",
       "...                       ...                     ...\n",
       "189602                AIM_2_1       EMF33_tax_lo_none\n",
       "190069          POLES_ADVANCE      ADVANCE_2030_Med2C\n",
       "190536                AIM_2_0           SSP2-Baseline\n",
       "191003            IMAGE_3_0_2      EMF33_Med2C_limbio\n",
       "191470  REMIND-MAgPIE_1_7-3_0      EMF33_1.5C_cost100\n",
       "\n",
       "[411 rows x 2 columns]"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/plain": [
       "<scmdata.ScmRun (timeseries: 193581, timepoints: 107)>\n",
       "Time:\n",
       "\tStart: 1995-01-01T00:00:00\n",
       "\tEnd: 2105-01-01T00:00:00\n",
       "Meta:\n",
       "\t         climate_model methodology                  model      percentile  \\\n",
       "\t0       not_applicable       SR1.5          POLES_ADVANCE  not_applicable   \n",
       "\t1       not_applicable       SR1.5          POLES_ADVANCE  not_applicable   \n",
       "\t2       not_applicable       SR1.5          POLES_ADVANCE  not_applicable   \n",
       "\t3       not_applicable       SR1.5          POLES_ADVANCE  not_applicable   \n",
       "\t4       not_applicable       SR1.5          POLES_ADVANCE  not_applicable   \n",
       "\t...                ...         ...                    ...             ...   \n",
       "\t193576  not_applicable       SR1.5                AIM_2_1  not_applicable   \n",
       "\t193577  not_applicable       SR1.5          POLES_ADVANCE  not_applicable   \n",
       "\t193578  not_applicable       SR1.5                AIM_2_0  not_applicable   \n",
       "\t193579  not_applicable       SR1.5            IMAGE_3_0_2  not_applicable   \n",
       "\t193580  not_applicable       SR1.5  REMIND-MAgPIE_1_7-3_0  not_applicable   \n",
       "\t\n",
       "\t       region            scenario       unit  \\\n",
       "\t0       World   ADVANCE_2030_WB2C   Mt BC/yr   \n",
       "\t1       World   ADVANCE_2030_WB2C  Mt CH4/yr   \n",
       "\t2       World   ADVANCE_2030_WB2C   Mt CO/yr   \n",
       "\t3       World   ADVANCE_2030_WB2C  Mt CO2/yr   \n",
       "\t4       World   ADVANCE_2030_WB2C  Mt CO2/yr   \n",
       "\t...       ...                 ...        ...   \n",
       "\t193576  World   EMF33_tax_lo_none     Gt CO2   \n",
       "\t193577  World  ADVANCE_2030_Med2C     Gt CO2   \n",
       "\t193578  World       SSP2-Baseline     Gt CO2   \n",
       "\t193579  World  EMF33_Med2C_limbio     Gt CO2   \n",
       "\t193580  World  EMF33_1.5C_cost100     Gt CO2   \n",
       "\t\n",
       "\t                                             variable  \n",
       "\t0                                        Emissions|BC  \n",
       "\t1                                       Emissions|CH4  \n",
       "\t2                                        Emissions|CO  \n",
       "\t3                                 Emissions|CO2|AFOLU  \n",
       "\t4       Emissions|CO2|Energy and Industrial Processes  \n",
       "\t...                                               ...  \n",
       "\t193576                       Cumulative Emissions|CO2  \n",
       "\t193577                       Cumulative Emissions|CO2  \n",
       "\t193578                       Cumulative Emissions|CO2  \n",
       "\t193579                       Cumulative Emissions|CO2  \n",
       "\t193580                       Cumulative Emissions|CO2  \n",
       "\t\n",
       "\t[193581 rows x 8 columns]"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "Saving to database: 0it [00:00, ?it/s]"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/javascript": [
       "\n",
       "            setTimeout(function() {\n",
       "                var nbb_cell_id = 7;\n",
       "                var nbb_unformatted_code = \"for ar6_id, methodology in (\\n    (utils.AR6_OUTPUT_SR15_RAW_ID, \\\"SR1.5\\\"),\\n    (utils.AR6_OUTPUT_SR15_RAW_RCMIP_PHASE_2_CONFIG_ID, \\\"SR1.5\\\"),\\n):\\n    files_to_read = glob.glob(\\n        os.path.join(utils.DATA_DIR, \\\"raw\\\", \\\"ar6-output\\\", ar6_id, \\\"*alloutput*.xlsx\\\")\\n    )\\n\\n    save_files_to_db(\\n        files_to_read,\\n        os.path.join(utils.DATA_DIR, \\\"processed\\\", \\\"ar6-output\\\", \\\"MAGICC\\\", ar6_id),\\n        methodology,\\n    )\";\n",
       "                var nbb_formatted_code = \"for ar6_id, methodology in (\\n    (utils.AR6_OUTPUT_SR15_RAW_ID, \\\"SR1.5\\\"),\\n    (utils.AR6_OUTPUT_SR15_RAW_RCMIP_PHASE_2_CONFIG_ID, \\\"SR1.5\\\"),\\n):\\n    files_to_read = glob.glob(\\n        os.path.join(utils.DATA_DIR, \\\"raw\\\", \\\"ar6-output\\\", ar6_id, \\\"*alloutput*.xlsx\\\")\\n    )\\n\\n    save_files_to_db(\\n        files_to_read,\\n        os.path.join(utils.DATA_DIR, \\\"processed\\\", \\\"ar6-output\\\", \\\"MAGICC\\\", ar6_id),\\n        methodology,\\n    )\";\n",
       "                var nbb_cells = Jupyter.notebook.get_cells();\n",
       "                for (var i = 0; i < nbb_cells.length; ++i) {\n",
       "                    if (nbb_cells[i].input_prompt_number == nbb_cell_id) {\n",
       "                        if (nbb_cells[i].get_text() == nbb_unformatted_code) {\n",
       "                             nbb_cells[i].set_text(nbb_formatted_code);\n",
       "                        }\n",
       "                        break;\n",
       "                    }\n",
       "                }\n",
       "            }, 500);\n",
       "            "
      ],
      "text/plain": [
       "<IPython.core.display.Javascript object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "for ar6_id, methodology in (\n",
    "    (utils.AR6_OUTPUT_SR15_RAW_ID, \"SR1.5\"),\n",
    "    (utils.AR6_OUTPUT_SR15_RAW_RCMIP_PHASE_2_CONFIG_ID, \"SR1.5\"),\n",
    "):\n",
    "    files_to_read = glob.glob(\n",
    "        os.path.join(utils.DATA_DIR, \"raw\", \"ar6-output\", ar6_id, \"*alloutput*.xlsx\")\n",
    "    )\n",
    "\n",
    "    save_files_to_db(\n",
    "        files_to_read,\n",
    "        os.path.join(utils.DATA_DIR, \"processed\", \"ar6-output\", \"MAGICC\", ar6_id),\n",
    "        methodology,\n",
    "    )"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## FaIR"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 12,
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "1 files to read\n",
      "Reading files with 32 workers\n",
      "Finished\n"
     ]
    },
    {
     "data": {
      "text/plain": [
       "<scmdata.ScmRun (timeseries: 180840, timepoints: 107)>\n",
       "Time:\n",
       "\tStart: 1995-01-01T00:00:00\n",
       "\tEnd: 2105-01-01T00:00:00\n",
       "Meta:\n",
       "\t                    model region                scenario       unit  \\\n",
       "\t0                 AIM_2_0  World  ADVANCE_2020_1.5C-2100   Mt BC/yr   \n",
       "\t1                 AIM_2_0  World  ADVANCE_2020_1.5C-2100  Mt CH4/yr   \n",
       "\t2                 AIM_2_0  World  ADVANCE_2020_1.5C-2100   Mt CO/yr   \n",
       "\t3                 AIM_2_0  World  ADVANCE_2020_1.5C-2100  Mt CO2/yr   \n",
       "\t4                 AIM_2_0  World  ADVANCE_2020_1.5C-2100  Mt CO2/yr   \n",
       "\t...                   ...    ...                     ...        ...   \n",
       "\t180835  WITCH-GLOBIOM_4_4  World       CD-LINKS_NoPolicy          K   \n",
       "\t180836  WITCH-GLOBIOM_4_4  World       CD-LINKS_NoPolicy          K   \n",
       "\t180837  WITCH-GLOBIOM_4_4  World       CD-LINKS_NoPolicy          K   \n",
       "\t180838  WITCH-GLOBIOM_4_4  World       CD-LINKS_NoPolicy          K   \n",
       "\t180839  WITCH-GLOBIOM_4_4  World       CD-LINKS_NoPolicy          K   \n",
       "\t\n",
       "\t                                                 variable  \n",
       "\t0                                            Emissions|BC  \n",
       "\t1                                           Emissions|CH4  \n",
       "\t2                                            Emissions|CO  \n",
       "\t3                                     Emissions|CO2|AFOLU  \n",
       "\t4           Emissions|CO2|Energy and Industrial Processes  \n",
       "\t...                                                   ...  \n",
       "\t180835  SR15 climate diagnostics|Surface Temperature (...  \n",
       "\t180836  SR15 climate diagnostics|Surface Temperature (...  \n",
       "\t180837  SR15 climate diagnostics|Surface Temperature (...  \n",
       "\t180838  SR15 climate diagnostics|Surface Temperature (...  \n",
       "\t180839  SR15 climate diagnostics|Surface Temperature (...  \n",
       "\t\n",
       "\t[180840 rows x 5 columns]"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/html": [
       "<div>\n",
       "<style scoped>\n",
       "    .dataframe tbody tr th:only-of-type {\n",
       "        vertical-align: middle;\n",
       "    }\n",
       "\n",
       "    .dataframe tbody tr th {\n",
       "        vertical-align: top;\n",
       "    }\n",
       "\n",
       "    .dataframe thead th {\n",
       "        text-align: right;\n",
       "    }\n",
       "</style>\n",
       "<table border=\"1\" class=\"dataframe\">\n",
       "  <thead>\n",
       "    <tr style=\"text-align: right;\">\n",
       "      <th></th>\n",
       "      <th>model</th>\n",
       "      <th>scenario</th>\n",
       "    </tr>\n",
       "  </thead>\n",
       "  <tbody>\n",
       "    <tr>\n",
       "      <th>0</th>\n",
       "      <td>AIM_2_0</td>\n",
       "      <td>ADVANCE_2020_1.5C-2100</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>440</th>\n",
       "      <td>AIM_2_0</td>\n",
       "      <td>ADVANCE_2020_Med2C</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>880</th>\n",
       "      <td>AIM_2_0</td>\n",
       "      <td>ADVANCE_2020_WB2C</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1320</th>\n",
       "      <td>AIM_2_0</td>\n",
       "      <td>ADVANCE_2030_Med2C</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>1760</th>\n",
       "      <td>AIM_2_0</td>\n",
       "      <td>ADVANCE_2030_Price1.5C</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>...</th>\n",
       "      <td>...</td>\n",
       "      <td>...</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>178640</th>\n",
       "      <td>WITCH-GLOBIOM_4_4</td>\n",
       "      <td>CD-LINKS_NPi</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>179080</th>\n",
       "      <td>WITCH-GLOBIOM_4_4</td>\n",
       "      <td>CD-LINKS_NPi2020_1000</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>179520</th>\n",
       "      <td>WITCH-GLOBIOM_4_4</td>\n",
       "      <td>CD-LINKS_NPi2020_1600</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>179960</th>\n",
       "      <td>WITCH-GLOBIOM_4_4</td>\n",
       "      <td>CD-LINKS_NPi2020_400</td>\n",
       "    </tr>\n",
       "    <tr>\n",
       "      <th>180400</th>\n",
       "      <td>WITCH-GLOBIOM_4_4</td>\n",
       "      <td>CD-LINKS_NoPolicy</td>\n",
       "    </tr>\n",
       "  </tbody>\n",
       "</table>\n",
       "<p>411 rows × 2 columns</p>\n",
       "</div>"
      ],
      "text/plain": [
       "                    model                scenario\n",
       "0                 AIM_2_0  ADVANCE_2020_1.5C-2100\n",
       "440               AIM_2_0      ADVANCE_2020_Med2C\n",
       "880               AIM_2_0       ADVANCE_2020_WB2C\n",
       "1320              AIM_2_0      ADVANCE_2030_Med2C\n",
       "1760              AIM_2_0  ADVANCE_2030_Price1.5C\n",
       "...                   ...                     ...\n",
       "178640  WITCH-GLOBIOM_4_4            CD-LINKS_NPi\n",
       "179080  WITCH-GLOBIOM_4_4   CD-LINKS_NPi2020_1000\n",
       "179520  WITCH-GLOBIOM_4_4   CD-LINKS_NPi2020_1600\n",
       "179960  WITCH-GLOBIOM_4_4    CD-LINKS_NPi2020_400\n",
       "180400  WITCH-GLOBIOM_4_4       CD-LINKS_NoPolicy\n",
       "\n",
       "[411 rows x 2 columns]"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "text/plain": [
       "<scmdata.ScmRun (timeseries: 182484, timepoints: 107)>\n",
       "Time:\n",
       "\tStart: 1995-01-01T00:00:00\n",
       "\tEnd: 2105-01-01T00:00:00\n",
       "Meta:\n",
       "\t         climate_model methodology              model      percentile region  \\\n",
       "\t0       not_applicable       SR1.5            AIM_2_0  not_applicable  World   \n",
       "\t1       not_applicable       SR1.5            AIM_2_0  not_applicable  World   \n",
       "\t2       not_applicable       SR1.5            AIM_2_0  not_applicable  World   \n",
       "\t3       not_applicable       SR1.5            AIM_2_0  not_applicable  World   \n",
       "\t4       not_applicable       SR1.5            AIM_2_0  not_applicable  World   \n",
       "\t...                ...         ...                ...             ...    ...   \n",
       "\t182479  not_applicable       SR1.5  WITCH-GLOBIOM_4_4  not_applicable  World   \n",
       "\t182480  not_applicable       SR1.5  WITCH-GLOBIOM_4_4  not_applicable  World   \n",
       "\t182481  not_applicable       SR1.5  WITCH-GLOBIOM_4_4  not_applicable  World   \n",
       "\t182482  not_applicable       SR1.5  WITCH-GLOBIOM_4_4  not_applicable  World   \n",
       "\t182483  not_applicable       SR1.5  WITCH-GLOBIOM_4_4  not_applicable  World   \n",
       "\t\n",
       "\t                      scenario       unit  \\\n",
       "\t0       ADVANCE_2020_1.5C-2100   Mt BC/yr   \n",
       "\t1       ADVANCE_2020_1.5C-2100  Mt CH4/yr   \n",
       "\t2       ADVANCE_2020_1.5C-2100   Mt CO/yr   \n",
       "\t3       ADVANCE_2020_1.5C-2100  Mt CO2/yr   \n",
       "\t4       ADVANCE_2020_1.5C-2100  Mt CO2/yr   \n",
       "\t...                        ...        ...   \n",
       "\t182479            CD-LINKS_NPi     Gt CO2   \n",
       "\t182480   CD-LINKS_NPi2020_1000     Gt CO2   \n",
       "\t182481   CD-LINKS_NPi2020_1600     Gt CO2   \n",
       "\t182482    CD-LINKS_NPi2020_400     Gt CO2   \n",
       "\t182483       CD-LINKS_NoPolicy     Gt CO2   \n",
       "\t\n",
       "\t                                             variable  \n",
       "\t0                                        Emissions|BC  \n",
       "\t1                                       Emissions|CH4  \n",
       "\t2                                        Emissions|CO  \n",
       "\t3                                 Emissions|CO2|AFOLU  \n",
       "\t4       Emissions|CO2|Energy and Industrial Processes  \n",
       "\t...                                               ...  \n",
       "\t182479                       Cumulative Emissions|CO2  \n",
       "\t182480                       Cumulative Emissions|CO2  \n",
       "\t182481                       Cumulative Emissions|CO2  \n",
       "\t182482                       Cumulative Emissions|CO2  \n",
       "\t182483                       Cumulative Emissions|CO2  \n",
       "\t\n",
       "\t[182484 rows x 8 columns]"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/vnd.jupyter.widget-view+json": {
       "model_id": "",
       "version_major": 2,
       "version_minor": 0
      },
      "text/plain": [
       "Saving to database: 0it [00:00, ?it/s]"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "application/javascript": [
       "\n",
       "            setTimeout(function() {\n",
       "                var nbb_cell_id = 12;\n",
       "                var nbb_unformatted_code = \"for source_dir, idd, methodology in (\\n    (\\n        os.path.join(\\n            utils.DATA_DIR,\\n            \\\"raw\\\",\\n            \\\"ar6-output\\\",\\n            \\\"20211014-sr15-run-fair\\\",\\n        ),\\n        \\\"sr15-processing\\\",\\n        \\\"SR1.5\\\",\\n    ),\\n):\\n    files_to_read = glob.glob(os.path.join(source_dir, \\\"*alloutput*.xlsx\\\"))\\n    output_dir = os.path.join(utils.DATA_DIR, \\\"processed\\\", \\\"ar6-output\\\", \\\"fair\\\", idd)\\n\\n    save_files_to_db(\\n        files_to_read,\\n        output_dir,\\n        methodology,\\n    )\";\n",
       "                var nbb_formatted_code = \"for source_dir, idd, methodology in (\\n    (\\n        os.path.join(\\n            utils.DATA_DIR,\\n            \\\"raw\\\",\\n            \\\"ar6-output\\\",\\n            \\\"20211014-sr15-run-fair\\\",\\n        ),\\n        \\\"sr15-processing\\\",\\n        \\\"SR1.5\\\",\\n    ),\\n):\\n    files_to_read = glob.glob(os.path.join(source_dir, \\\"*alloutput*.xlsx\\\"))\\n    output_dir = os.path.join(utils.DATA_DIR, \\\"processed\\\", \\\"ar6-output\\\", \\\"fair\\\", idd)\\n\\n    save_files_to_db(\\n        files_to_read,\\n        output_dir,\\n        methodology,\\n    )\";\n",
       "                var nbb_cells = Jupyter.notebook.get_cells();\n",
       "                for (var i = 0; i < nbb_cells.length; ++i) {\n",
       "                    if (nbb_cells[i].input_prompt_number == nbb_cell_id) {\n",
       "                        if (nbb_cells[i].get_text() == nbb_unformatted_code) {\n",
       "                             nbb_cells[i].set_text(nbb_formatted_code);\n",
       "                        }\n",
       "                        break;\n",
       "                    }\n",
       "                }\n",
       "            }, 500);\n",
       "            "
      ],
      "text/plain": [
       "<IPython.core.display.Javascript object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "for source_dir, idd, methodology in (\n",
    "    (\n",
    "        os.path.join(\n",
    "            utils.DATA_DIR,\n",
    "            \"raw\",\n",
    "            \"ar6-output\",\n",
    "            \"20211014-sr15-run-fair\",\n",
    "        ),\n",
    "        \"sr15-processing\",\n",
    "        \"SR1.5\",\n",
    "    ),\n",
    "):\n",
    "    files_to_read = glob.glob(os.path.join(source_dir, \"*alloutput*.xlsx\"))\n",
    "    output_dir = os.path.join(utils.DATA_DIR, \"processed\", \"ar6-output\", \"fair\", idd)\n",
    "\n",
    "    save_files_to_db(\n",
    "        files_to_read,\n",
    "        output_dir,\n",
    "        methodology,\n",
    "    )"
   ]
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 3 (ipykernel)",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.7.12"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 4
}
